@@ -68,12 +68,14 @@ setAs('RasterLayer', 'SpatialPolygonsDataFrame',
 	}
 )
 
-setAs('Extent', 'SpatialPolygonsDataFrame', 
+setAs('Extent', 'SpatialPolygons', 
 	function(from){ 
 		return( polygonFromExtent(from)) 
 	}
 )
 
+
+
 setAs('Raster', 'SpatialPoints', 
 	function(from) { 
 		return( SpatialPoints(rasterToPoints(from, spatial=FALSE)[,1:2]) )
